********
Citation
********

If you use Pylians consider citing it thourgh:

::

   @MISC{Pylians,
       author = {{Villaescusa-Navarro}, Francisco},
       title = "{Pylians: Python libraries for the analysis of numerical simulations}",
       keywords = {Software},
       howpublished = {Astrophysics Source Code Library, record ascl:1811.008},
       year = 2018,
       month = nov,
       eid = {ascl:1811.008},
       pages = {ascl:1811.008},
       archivePrefix = {ascl},
       eprint = {1811.008},
       adsurl = {https://ui.adsabs.harvard.edu/abs/2018ascl.soft11008V},
       adsnote = {Provided by the SAO/NASA Astrophysics Data System}
   }
